@@ -1,5 +1,7 @@
 from typing import List
+
 from beautifultable import BeautifulTable
+from beautifultable.enums import STYLE_BOX_ROUNDED
 
 
 def make_table(header: List[str], content: List[List[str]]):
@@ -7,7 +9,7 @@ def make_table(header: List[str], content: List[List[str]]):
     table.columns.header = header
     for row in content:
         table.rows.append(row)
-    table.set_style(BeautifulTable.STYLE_BOX_ROUNDED)
+    table.set_style(STYLE_BOX_ROUNDED)
     table.columns.header.separator = '═'
     table.columns.header.junction = '╪'
     table.border.header_left = '╞'
